@@ -3,9 +3,9 @@
 import logging as _logging
 
 from . import spells, types
+from ._common import DEFAULT_PRIORITY, from_date, to_date
 from ._group import TodoGroup
 from ._magic import MagicTodoMixin
-from ._shared import DEFAULT_PRIORITY, from_date, to_date
 from ._todo import Todo
 
 
@@ -22,6 +22,6 @@ __all__ = [
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.8.1"
+__version__ = "0.8.2"
 
 _logging.getLogger(__name__).addHandler(_logging.NullHandler())
